Package: EMJMCMC
Type: Package
Title: Evolutionary Mode Jumping Markov Chain Monte Carlo Expert
        Toolbox
Version: 1.5.0
Date: 2024-05-02
Authors@R: 
  c(
    person("Aliaksandr", "Hubin", email = "aliaksah@math.uio.no", role = c("aut")),
    person("Waldir", "Leoncio", email = "w.l.netto@medisin.uio.no", role = c("cre","aut")),
    person("Geir", "Storvik", role = c("ctb")),
    person("Florian", "Frommlet", role = c("ctb"))
  )
Maintainer: Waldir Leoncio <w.l.netto@medisin.uio.no>
Description: Implementation of the Mode Jumping Markov Chain Monte Carlo algorithm from Hubin, A., Storvik, G. (2018) <doi:10.1016/j.csda.2018.05.020>, Genetically Modified Mode Jumping Markov Chain Monte Carlo from Hubin, A., Storvik, G., & Frommlet, F. (2020) <doi:10.1214/18-BA1141>, Hubin, A., Storvik, G., & Frommlet, F. (2021) <doi:10.1613/jair.1.13047>, and Hubin, A., Heinze, G., & De Bin, R. (2023) <doi:10.3390/fractalfract7090641>, and Reversible Genetically Modified Mode Jumping Markov Chain Monte Carlo from Hubin, A., Frommlet, F., & Storvik, G. (2021) <doi:10.48550/arXiv.2110.05316>, which allow for estimating posterior model probabilities and Bayesian model averaging across a wide set of Bayesian models including linear, generalized linear, generalized linear mixed, generalized nonlinear, generalized nonlinear mixed, and logic regression models.
License: GPL
Depends: R (>= 3.4.1), bigmemory
Imports: glmnet, biglm, hash, BAS, stringi, parallel, methods,
        speedglm, stats, withr
RoxygenNote: 7.3.1
Suggests: testthat (>= 3.0.0), bindata, clusterGeneration, reshape2
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-05-02 07:33:43 UTC; waldir
Author: Aliaksandr Hubin [aut],
  Waldir Leoncio [cre, aut],
  Geir Storvik [ctb],
  Florian Frommlet [ctb]
Repository: CRAN
Date/Publication: 2024-05-03 23:10:02 UTC
Built: R 4.2.3; ; 2024-05-04 02:28:19 UTC; unix
