# Generated by roxygen2: do not edit by hand

export(LogicRegr)
export(erf)
export(estimate.bas.glm)
export(estimate.bas.lm)
export(estimate.bigm)
export(estimate.elnet)
export(estimate.gamma.cpen)
export(estimate.gamma.cpen_2)
export(estimate.glm)
export(estimate.logic.glm)
export(estimate.logic.lm)
export(estimate.speedglm)
export(m)
export(parall.gmj)
export(pinferunemjmcmc)
export(runemjmcmc)
export(sigmoid)
export(simplify.formula)
export(truncfactorial)
importFrom(bigmemory,attach.resource)
importFrom(bigmemory,big.matrix)
importFrom(bigmemory,describe)
importFrom(hash,del)
importFrom(methods,new)
importFrom(stats,coefficients)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stringi,stri_count_fixed)
importFrom(stringi,stri_locate_all)
importFrom(stringi,stri_paste)
importFrom(stringi,stri_replace_all)
importFrom(stringi,stri_split_fixed)
importFrom(utils,capture.output)
